"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeJavaScriptConfig = void 0;
const imports_1 = require("./imports");
const renames_1 = require("./renames");
const writeJavaScriptConfig = ({ imports, project, sourceFiles, renames }) => __awaiter(void 0, void 0, void 0, function* () {
    const fileConversion = {
        files: {
            renameExtensions: printRenames(renames),
        },
    };
    const fixConversion = {
        fixes: {
            incompleteTypes: true,
            missingProperties: true,
            noImplicitAny: true,
        },
    };
    const shared = (include) => (Object.assign(Object.assign({}, (include && { include })), { project }));
    const allConversions = imports === imports_1.InitializationImports.Yes
        ? [
            Object.assign(Object.assign(Object.assign({}, fileConversion), { fixes: {
                    importExtensions: true,
                } }), shared(sourceFiles ? [sourceFiles] : undefined)),
            Object.assign(Object.assign({}, fixConversion), shared(sourceFiles
                ? renames === renames_1.InitializationRenames.Auto
                    ? renameSourceFilesExtensionsAuto(sourceFiles)
                    : renames === renames_1.InitializationRenames.TS
                        ? renameSourceFilesExtensions(sourceFiles, "ts")
                        : renameSourceFilesExtensions(sourceFiles, "tsx")
                : undefined)),
        ]
        : Object.assign(Object.assign(Object.assign({}, fileConversion), fixConversion), shared(sourceFiles ? [sourceFiles] : undefined));
    return allConversions;
});
exports.writeJavaScriptConfig = writeJavaScriptConfig;
const printRenames = (renames) => {
    switch (renames) {
        case renames_1.InitializationRenames.Auto:
            return true;
        case renames_1.InitializationRenames.TS:
            return "ts";
        case renames_1.InitializationRenames.TSX:
            return "tsx";
    }
};
function renameSourceFilesExtensionsAuto(sourceFiles) {
    for (const [original, replacement] of [
        [/\{js,jsx\}/, "{ts,tsx}"],
        [/\.js$/, ".{ts,tsx}"],
    ]) {
        sourceFiles = sourceFiles.replace(original, replacement);
    }
    return renameSourceFilesExtensions(sourceFiles, "ts");
}
function renameSourceFilesExtensions(sourceFiles, extension) {
    return [sourceFiles.replace(/(\.|{)js/, `$1${extension}`).replace(new RegExp(`{${extension},jsx?}`), extension)];
}
//# sourceMappingURL=writeJavaScriptConfig.js.map