"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const getNewFileName_1 = require("./getNewFileName");
describe(getNewFileName_1.getNewFileName, () => {
    it("returns a .ts path when renameExtensions is ts", () => __awaiter(void 0, void 0, void 0, function* () {
        const actual = yield getNewFileName_1.getNewFileName("ts", "path/name.js", jest.fn());
        expect(actual).toBe("path/name.ts");
    }));
    it("returns a .tsx path when renameExtensions is tsx", () => __awaiter(void 0, void 0, void 0, function* () {
        const actual = yield getNewFileName_1.getNewFileName("tsx", "path/name.js", jest.fn());
        expect(actual).toBe("path/name.tsx");
    }));
    it.each([
        { extension: ".ts", name: "no closing tags", text: "<>" },
        { extension: ".tsx", name: "an intrinsic closing tag", text: "< /div >" },
        { extension: ".tsx", name: "a custom closing tag", text: "< /Custom.Tag >" },
        { extension: ".tsx", name: "a fragment closing tag", text: "</>" },
        { extension: ".tsx", name: "a self closing tag", text: "/>" },
    ])("returns a $extension path when renameExtensions is true and the file contains $name", ({ extension, text }) => __awaiter(void 0, void 0, void 0, function* () {
        const actual = yield getNewFileName_1.getNewFileName(true, "path/name.js", jest.fn().mockResolvedValue(`
            ${text}        
            `));
        expect(actual).toBe(`path/name${extension}`);
    }));
});
//# sourceMappingURL=getNewFileName.test.js.map