"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProviderFromProviders = void 0;
/**
 * Creates a provider that runs through a series of providers.
 *
 * @param providers   Providers to return changes from, in order.
 * @returns Single provider equivalent to the given providers, in order.
 */
const createProviderFromProviders = (options, providerCreators) => {
    let index = -1;
    let provider;
    const multiProvider = () => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b;
        if (!provider) {
            for (index += 1; index < providerCreators.length; index += 1) {
                provider = providerCreators[index](options);
                if (provider) {
                    break;
                }
            }
            if (!provider) {
                return { fileMutations: undefined };
            }
        }
        const results = yield provider();
        if (!results) {
            provider = undefined;
            return multiProvider();
        }
        options = (_a = results.newOptions) !== null && _a !== void 0 ? _a : options;
        if (((_b = results.mutationsWave) === null || _b === void 0 ? void 0 : _b.fileMutations) === undefined) {
            return { fileMutations: undefined };
        }
        return results.mutationsWave;
    });
    return multiProvider;
};
exports.createProviderFromProviders = createProviderFromProviders;
//# sourceMappingURL=createProviderFromProviders.js.map