"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPostProcessingProvider = void 0;
const createSingleUseProvider_1 = require("../createSingleUseProvider");
const runCommand_1 = require("./missingTypes/runCommand");
/**
 * Creates a mutations provider to run any post-processing shell scripts.
 *
 * @param allModifiedFilePaths   Unique names of all files that were modified.
 * @returns Mutations provider to run post-processing shell scripts, if needed.
 */
const createPostProcessingProvider = (allModifiedFilePaths) => {
    return createSingleUseProvider_1.createSingleUseProvider("Running post-processing scripts", (options) => {
        if (options.postProcess.shell.length === 0) {
            return undefined;
        }
        return () => __awaiter(void 0, void 0, void 0, function* () {
            for (const shellCommand of options.postProcess.shell) {
                yield runCommand_1.runCommand(options, [...shellCommand, ...Array.from(allModifiedFilePaths)]);
            }
            return {
                mutationsWave: {},
            };
        });
    });
};
exports.createPostProcessingProvider = createPostProcessingProvider;
//# sourceMappingURL=createPostProcessingProvider.js.map